import datetime
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.command_parameter_meta import CommandParameterMeta
    from ..models.file_info import FileInfo


T = TypeVar("T", bound="CommandParameter")


@attr.s(auto_attribs=True)
class CommandParameter:
    """
    Attributes:
        scrubber_time (datetime.datetime): Timestamp associated with this command.
        value (Union[Unset, str]): Enter your parameter and value. This string will be passed along with your command.
        meta (Union[Unset, CommandParameterMeta]): You can use this to add many parameters in a more structured way.
        files (Union[Unset, List['FileInfo']]): File(s) to be sent as a parameter with your command. Up to five files
            allowed.
    """

    scrubber_time: datetime.datetime
    value: Union[Unset, str] = UNSET
    meta: Union[Unset, "CommandParameterMeta"] = UNSET
    files: Union[Unset, List["FileInfo"]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        scrubber_time = self.scrubber_time.isoformat()

        value = self.value
        meta: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.meta, Unset):
            meta = self.meta.to_dict()

        files: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.files, Unset):
            files = []
            for files_item_data in self.files:
                files_item = files_item_data.to_dict()

                files.append(files_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "scrubberTime": scrubber_time,
            }
        )
        if value is not UNSET:
            field_dict["value"] = value
        if meta is not UNSET:
            field_dict["meta"] = meta
        if files is not UNSET:
            field_dict["files"] = files

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.command_parameter_meta import CommandParameterMeta
        from ..models.file_info import FileInfo

        d = src_dict.copy()
        scrubber_time = isoparse(d.pop("scrubberTime"))

        value = d.pop("value", UNSET)

        _meta = d.pop("meta", UNSET)
        meta: Union[Unset, CommandParameterMeta]
        if isinstance(_meta, Unset):
            meta = UNSET
        else:
            meta = CommandParameterMeta.from_dict(_meta)

        files = []
        _files = d.pop("files", UNSET)
        for files_item_data in _files or []:
            files_item = FileInfo.from_dict(files_item_data)

            files.append(files_item)

        command_parameter = cls(
            scrubber_time=scrubber_time,
            value=value,
            meta=meta,
            files=files,
        )

        command_parameter.additional_properties = d
        return command_parameter

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class PartialScheduleType(str, Enum):
    COMMAND = "command"
    RUN_WORKFLOW = "run-workflow"
    GENERATE_INSIGHTS = "generate-insights"

    def __str__(self) -> str:
        return str(self.value)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/model/v1/file.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/model/v1/file.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aprotos/model/v1/file.proto\x12\x08v1.model\"D\n\x04\x46ile\x12\r\n\x03url\x18\x01 \x01(\tH\x00\x12\r\n\x03raw\x18\x02 \x01(\x0cH\x00\x12\x10\n\x08\x66ilename\x18\x03 \x01(\tB\x06\n\x04\x64\x61taJ\x04\x08\x04\x10\x05\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.model.v1.file_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/model'
  _globals['_FILE']._serialized_start=40
  _globals['_FILE']._serialized_end=108
# @@protoc_insertion_point(module_scope)



from enum import Enum


class UsageRecordType(str, Enum):
    DEVICE_COUNT = "device-count"
    DATAPOINT_COUNT = "datapoint-count"
    ASSET_COUNT = "asset-count"
    DATA_STORAGE = "data-storage"
    TURN_NETWORK = "turn-network"
    ADVANCED_CONFIGURATION = "advanced-configuration"
    ANALYTICS = "analytics"
    CUSTOMER_PORTAL = "customer-portal"
    DATA_EXPORT = "data-export"
    DATA_RETENTION = "data-retention"
    SUPPORT = "support"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.application_context import ApplicationContext
    from ..models.suggestion_structure_schema import SuggestionStructureSchema


T = TypeVar("T", bound="SuggestionRequest")


@attr.s(auto_attribs=True)
class SuggestionRequest:
    """
    Attributes:
        prompt (str):
        structures (List['SuggestionStructureSchema']):
        model (Union[Unset, str]):
        system_context (Union[Unset, ApplicationContext]):
    """

    prompt: str
    structures: List["SuggestionStructureSchema"]
    model: Union[Unset, str] = UNSET
    system_context: Union[Unset, "ApplicationContext"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        prompt = self.prompt
        structures = []
        for structures_item_data in self.structures:
            structures_item = structures_item_data.to_dict()

            structures.append(structures_item)

        model = self.model
        system_context: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.system_context, Unset):
            system_context = self.system_context.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "prompt": prompt,
                "structures": structures,
            }
        )
        if model is not UNSET:
            field_dict["model"] = model
        if system_context is not UNSET:
            field_dict["systemContext"] = system_context

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.application_context import ApplicationContext
        from ..models.suggestion_structure_schema import SuggestionStructureSchema

        d = src_dict.copy()
        prompt = d.pop("prompt")

        structures = []
        _structures = d.pop("structures")
        for structures_item_data in _structures:
            structures_item = SuggestionStructureSchema.from_dict(structures_item_data)

            structures.append(structures_item)

        model = d.pop("model", UNSET)

        _system_context = d.pop("systemContext", UNSET)
        system_context: Union[Unset, ApplicationContext]
        if isinstance(_system_context, Unset):
            system_context = UNSET
        else:
            system_context = ApplicationContext.from_dict(_system_context)

        suggestion_request = cls(
            prompt=prompt,
            structures=structures,
            model=model,
            system_context=system_context,
        )

        suggestion_request.additional_properties = d
        return suggestion_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from formant.sdk.cloud.v2.src.resources.resources import Resources
from formant.sdk.cloud.v2.formant_query_api_client.api.query import query_controller_query
from formant.sdk.cloud.v2.formant_query_api_client.models.query import Query

class Queries(Resources):

    def query(self, query: Query, app_id='formant/sdk'):
        """Queries objects based on data types"""
        client = self._get_client()
        response = query_controller_query.sync_detailed(client=client, json_body=query, app_id=app_id)
        return response

    async def query_async(self, query: Query, app_id='formant/sdk'):
        """Queries objects based on data types"""
        client = self._get_client()
        response = await query_controller_query.asyncio_detailed(client=client, json_body=query, app_id=app_id)
        return response


import datetime
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

import attr
from dateutil.parser import isoparse

from ..models.intervention_request_intervention_type import InterventionRequestInterventionType
from ..models.intervention_request_severity import InterventionRequestSeverity
from ..models.intervention_request_stream_type import InterventionRequestStreamType
from ..models.intervention_request_type import InterventionRequestType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.intervention_request_metadata import InterventionRequestMetadata
    from ..models.intervention_request_tags import InterventionRequestTags
    from ..models.labeling_request_data import LabelingRequestData
    from ..models.physical_request_data import PhysicalRequestData
    from ..models.selection_request_data import SelectionRequestData
    from ..models.teleop_request_data import TeleopRequestData


T = TypeVar("T", bound="InterventionRequest")


@attr.s(auto_attribs=True)
class InterventionRequest:
    """
    Attributes:
        data (Union['LabelingRequestData', 'PhysicalRequestData', 'SelectionRequestData', 'TeleopRequestData']):
        time (datetime.datetime): Start time of the data range relevant to this event.
        type (Union[Unset, InterventionRequestType]): Enter `intervention-request`.
        intervention_type (Union[Unset, InterventionRequestInterventionType]): `selection` prompts user to select an
            option from a dropdown menu. `labeling` prompts user to draw a box around and object and give it a label.
        responses (Union[Unset, List[Any]]):
        agent_id (Union[Unset, str]): ID of the device which prompts this intervention request.
        severity (Union[Unset, InterventionRequestSeverity]): Severity of this event (`info`, `warning`, `error`, or
            `critical`).
        id (Union[Unset, str]):
        created_at (Union[Unset, datetime.datetime]):
        updated_at (Union[Unset, datetime.datetime]):
        tags (Union[Unset, InterventionRequestTags]):
        organization_id (Union[Unset, str]): ID of the organization in which to create this new event.
        end_time (Union[Unset, None, datetime.datetime]): End time of the data range relevant to this event.
        parent_id (Union[Unset, str]): If this custom event is related to another event, you can add the ID of that
            parent event here.
        metadata (Union[Unset, InterventionRequestMetadata]): User-customizable metadata associated with this event in
            key-value pair format.
        message (Union[Unset, str]): Message of this event. Must match the `message` field in the Formant UI when
            configuring a custom event.
        viewed (Union[Unset, bool]):
        device_id (Union[Unset, None, str]): ID of the device relevant to this event.
        stream_name (Union[Unset, None, str]):
        stream_type (Union[Unset, None, InterventionRequestStreamType]):
        event_trigger_id (Union[Unset, None, str]):
        notification_enabled (Union[Unset, bool]): Set this to `true` to enable notifications for this event.
        deleted_at (Union[Unset, None, datetime.datetime]):
    """

    data: Union["LabelingRequestData", "PhysicalRequestData", "SelectionRequestData", "TeleopRequestData"]
    time: datetime.datetime
    type: Union[Unset, InterventionRequestType] = UNSET
    intervention_type: Union[Unset, InterventionRequestInterventionType] = UNSET
    responses: Union[Unset, List[Any]] = UNSET
    agent_id: Union[Unset, str] = UNSET
    severity: Union[Unset, InterventionRequestSeverity] = UNSET
    id: Union[Unset, str] = UNSET
    created_at: Union[Unset, datetime.datetime] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET
    tags: Union[Unset, "InterventionRequestTags"] = UNSET
    organization_id: Union[Unset, str] = UNSET
    end_time: Union[Unset, None, datetime.datetime] = UNSET
    parent_id: Union[Unset, str] = UNSET
    metadata: Union[Unset, "InterventionRequestMetadata"] = UNSET
    message: Union[Unset, str] = UNSET
    viewed: Union[Unset, bool] = UNSET
    device_id: Union[Unset, None, str] = UNSET
    stream_name: Union[Unset, None, str] = UNSET
    stream_type: Union[Unset, None, InterventionRequestStreamType] = UNSET
    event_trigger_id: Union[Unset, None, str] = UNSET
    notification_enabled: Union[Unset, bool] = UNSET
    deleted_at: Union[Unset, None, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        from ..models.labeling_request_data import LabelingRequestData
        from ..models.selection_request_data import SelectionRequestData
        from ..models.teleop_request_data import TeleopRequestData

        data: Dict[str, Any]

        if isinstance(self.data, SelectionRequestData):
            data = self.data.to_dict()

        elif isinstance(self.data, LabelingRequestData):
            data = self.data.to_dict()

        elif isinstance(self.data, TeleopRequestData):
            data = self.data.to_dict()

        else:
            data = self.data.to_dict()

        time = self.time.isoformat()

        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type.value

        intervention_type: Union[Unset, str] = UNSET
        if not isinstance(self.intervention_type, Unset):
            intervention_type = self.intervention_type.value

        responses: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.responses, Unset):
            responses = self.responses

        agent_id = self.agent_id
        severity: Union[Unset, str] = UNSET
        if not isinstance(self.severity, Unset):
            severity = self.severity.value

        id = self.id
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        tags: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags.to_dict()

        organization_id = self.organization_id
        end_time: Union[Unset, None, str] = UNSET
        if not isinstance(self.end_time, Unset):
            end_time = self.end_time.isoformat() if self.end_time else None

        parent_id = self.parent_id
        metadata: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict()

        message = self.message
        viewed = self.viewed
        device_id = self.device_id
        stream_name = self.stream_name
        stream_type: Union[Unset, None, str] = UNSET
        if not isinstance(self.stream_type, Unset):
            stream_type = self.stream_type.value if self.stream_type else None

        event_trigger_id = self.event_trigger_id
        notification_enabled = self.notification_enabled
        deleted_at: Union[Unset, None, str] = UNSET
        if not isinstance(self.deleted_at, Unset):
            deleted_at = self.deleted_at.isoformat() if self.deleted_at else None

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "data": data,
                "time": time,
            }
        )
        if type is not UNSET:
            field_dict["type"] = type
        if intervention_type is not UNSET:
            field_dict["interventionType"] = intervention_type
        if responses is not UNSET:
            field_dict["responses"] = responses
        if agent_id is not UNSET:
            field_dict["agentId"] = agent_id
        if severity is not UNSET:
            field_dict["severity"] = severity
        if id is not UNSET:
            field_dict["id"] = id
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at
        if tags is not UNSET:
            field_dict["tags"] = tags
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if end_time is not UNSET:
            field_dict["endTime"] = end_time
        if parent_id is not UNSET:
            field_dict["parentId"] = parent_id
        if metadata is not UNSET:
            field_dict["metadata"] = metadata
        if message is not UNSET:
            field_dict["message"] = message
        if viewed is not UNSET:
            field_dict["viewed"] = viewed
        if device_id is not UNSET:
            field_dict["deviceId"] = device_id
        if stream_name is not UNSET:
            field_dict["streamName"] = stream_name
        if stream_type is not UNSET:
            field_dict["streamType"] = stream_type
        if event_trigger_id is not UNSET:
            field_dict["eventTriggerId"] = event_trigger_id
        if notification_enabled is not UNSET:
            field_dict["notificationEnabled"] = notification_enabled
        if deleted_at is not UNSET:
            field_dict["deletedAt"] = deleted_at

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.intervention_request_metadata import InterventionRequestMetadata
        from ..models.intervention_request_tags import InterventionRequestTags
        from ..models.labeling_request_data import LabelingRequestData
        from ..models.physical_request_data import PhysicalRequestData
        from ..models.selection_request_data import SelectionRequestData
        from ..models.teleop_request_data import TeleopRequestData

        d = src_dict.copy()

        def _parse_data(
            data: object,
        ) -> Union["LabelingRequestData", "PhysicalRequestData", "SelectionRequestData", "TeleopRequestData"]:
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                data_type_0 = SelectionRequestData.from_dict(data)

                return data_type_0
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                data_type_1 = LabelingRequestData.from_dict(data)

                return data_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                data_type_2 = TeleopRequestData.from_dict(data)

                return data_type_2
            except:  # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError()
            data_type_3 = PhysicalRequestData.from_dict(data)

            return data_type_3

        data = _parse_data(d.pop("data"))

        time = isoparse(d.pop("time"))

        _type = d.pop("type", UNSET)
        type: Union[Unset, InterventionRequestType]
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = InterventionRequestType(_type)

        _intervention_type = d.pop("interventionType", UNSET)
        intervention_type: Union[Unset, InterventionRequestInterventionType]
        if isinstance(_intervention_type, Unset):
            intervention_type = UNSET
        else:
            intervention_type = InterventionRequestInterventionType(_intervention_type)

        responses = cast(List[Any], d.pop("responses", UNSET))

        agent_id = d.pop("agentId", UNSET)

        _severity = d.pop("severity", UNSET)
        severity: Union[Unset, InterventionRequestSeverity]
        if isinstance(_severity, Unset):
            severity = UNSET
        else:
            severity = InterventionRequestSeverity(_severity)

        id = d.pop("id", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        _tags = d.pop("tags", UNSET)
        tags: Union[Unset, InterventionRequestTags]
        if isinstance(_tags, Unset):
            tags = UNSET
        else:
            tags = InterventionRequestTags.from_dict(_tags)

        organization_id = d.pop("organizationId", UNSET)

        _end_time = d.pop("endTime", UNSET)
        end_time: Union[Unset, None, datetime.datetime]
        if _end_time is None:
            end_time = None
        elif isinstance(_end_time, Unset):
            end_time = UNSET
        else:
            end_time = isoparse(_end_time)

        parent_id = d.pop("parentId", UNSET)

        _metadata = d.pop("metadata", UNSET)
        metadata: Union[Unset, InterventionRequestMetadata]
        if isinstance(_metadata, Unset):
            metadata = UNSET
        else:
            metadata = InterventionRequestMetadata.from_dict(_metadata)

        message = d.pop("message", UNSET)

        viewed = d.pop("viewed", UNSET)

        device_id = d.pop("deviceId", UNSET)

        stream_name = d.pop("streamName", UNSET)

        _stream_type = d.pop("streamType", UNSET)
        stream_type: Union[Unset, None, InterventionRequestStreamType]
        if _stream_type is None:
            stream_type = None
        elif isinstance(_stream_type, Unset):
            stream_type = UNSET
        else:
            stream_type = InterventionRequestStreamType(_stream_type)

        event_trigger_id = d.pop("eventTriggerId", UNSET)

        notification_enabled = d.pop("notificationEnabled", UNSET)

        _deleted_at = d.pop("deletedAt", UNSET)
        deleted_at: Union[Unset, None, datetime.datetime]
        if _deleted_at is None:
            deleted_at = None
        elif isinstance(_deleted_at, Unset):
            deleted_at = UNSET
        else:
            deleted_at = isoparse(_deleted_at)

        intervention_request = cls(
            data=data,
            time=time,
            type=type,
            intervention_type=intervention_type,
            responses=responses,
            agent_id=agent_id,
            severity=severity,
            id=id,
            created_at=created_at,
            updated_at=updated_at,
            tags=tags,
            organization_id=organization_id,
            end_time=end_time,
            parent_id=parent_id,
            metadata=metadata,
            message=message,
            viewed=viewed,
            device_id=device_id,
            stream_name=stream_name,
            stream_type=stream_type,
            event_trigger_id=event_trigger_id,
            notification_enabled=notification_enabled,
            deleted_at=deleted_at,
        )

        intervention_request.additional_properties = d
        return intervention_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class DeviceTeleopHardwareStreamConfigurationRtcStreamType(str, Enum):
    PING = "ping"
    PONG = "pong"
    PING_V2 = "ping-v2"
    PONG_V2 = "pong-v2"
    STREAM_CONTROL = "stream-control"
    STREAMS_INFO = "streams-info"
    AGENT_INFO = "agent-info"
    NUMERIC = "numeric"
    BOOLEAN = "boolean"
    BITSET = "bitset"
    TWIST = "twist"
    COMPRESSED_IMAGE = "compressed-image"
    H264_VIDEO_FRAME = "h264-video-frame"
    AUDIO_CHUNK = "audio-chunk"
    POSE = "pose"
    GOAL_ID = "goal-id"
    JOINT_STATE = "joint-state"
    POSE_WITH_COVARIANCE = "pose-with-covariance"
    POINT_CLOUD = "point-cloud"
    POINT = "point"
    MARKER_ARRAY = "marker-array"
    JSON_STRING = "json-string"
    ODOMETRY = "odometry"
    JOY = "joy"

    def __str__(self) -> str:
        return str(self.value)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/model/v1/health.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/model/v1/health.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cprotos/model/v1/health.proto\x12\x08v1.model\"L\n\x06Health\x12&\n\x06status\x18\x01 \x01(\x0e\x32\x16.v1.model.HealthStatus\x12\x11\n\x07skew_ms\x18\x02 \x01(\x03H\x00\x42\x07\n\x05\x63lock\"O\n\x07\x42\x61ttery\x12\x12\n\npercentage\x18\x01 \x01(\x01\x12\x0f\n\x07voltage\x18\x02 \x01(\x01\x12\x0f\n\x07\x63urrent\x18\x03 \x01(\x01\x12\x0e\n\x06\x63harge\x18\x04 \x01(\x01\"\xf4\x01\n\x0e\x42ufferMetadata\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x30\n(latest_ttl_stream_channel_buffered_bytes\x18\x02 \x01(\x04\x12.\n&reliable_stream_channel_buffered_bytes\x18\x03 \x01(\x04\x12\x35\n-latest_reliable_stream_channel_buffered_bytes\x18\x04 \x01(\x04\x12\x35\n-latest_try_once_stream_channel_buffered_bytes\x18\x05 \x01(\x04*`\n\x0cHealthStatus\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\x16\n\x12HEALTH_OPERATIONAL\x10\x01\x12\x12\n\x0eHEALTH_OFFLINE\x10\x02\x12\x10\n\x0cHEALTH_ERROR\x10\x03\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.model.v1.health_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/model'
  _globals['_HEALTHSTATUS']._serialized_start=448
  _globals['_HEALTHSTATUS']._serialized_end=544
  _globals['_HEALTH']._serialized_start=42
  _globals['_HEALTH']._serialized_end=118
  _globals['_BATTERY']._serialized_start=120
  _globals['_BATTERY']._serialized_end=199
  _globals['_BUFFERMETADATA']._serialized_start=202
  _globals['_BUFFERMETADATA']._serialized_end=446
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/model/v1/commands.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/model/v1/commands.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from formant.protos.model.v1 import datapoint_pb2 as protos_dot_model_dot_v1_dot_datapoint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eprotos/model/v1/commands.proto\x12\x08v1.model\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1fprotos/model/v1/datapoint.proto\"\xd0\x01\n\x0e\x43ommandRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\x12\x0e\n\x04text\x18\x03 \x01(\tH\x00\x12\x31\n\rscrubber_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12!\n\x05\x66iles\x18\x05 \x03(\x0b\x32\x12.v1.model.FileInfo\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0b\n\tparameter\"j\n\x0f\x43ommandResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12(\n\tdatapoint\x18\x03 \x01(\x0b\x32\x13.v1.model.DatapointH\x00\x42\x08\n\x06result\"1\n\x08\x46ileInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\"?\n\x10\x43ommandsMetadata\x12+\n\x08\x63ommands\x18\x01 \x03(\x0b\x32\x19.v1.model.CommandMetadata\"\xf2\x02\n\x0f\x43ommandMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x19\n\x11parameter_enabled\x18\x04 \x01(\x08\x12\x17\n\x0fparameter_value\x18\x05 \x01(\t\x12\x44\n\x0eparameter_meta\x18\x06 \x03(\x0b\x32,.v1.model.CommandMetadata.ParameterMetaEntry\x12\x0f\n\x07\x65nabled\x18\x07 \x01(\x08\x12\n\n\x02id\x18\x08 \x01(\t\x12\x31\n\x04tags\x18\t \x03(\x0b\x32#.v1.model.CommandMetadata.TagsEntry\x1a\x34\n\x12ParameterMetaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.model.v1.commands_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/model'
  _globals['_COMMANDMETADATA_PARAMETERMETAENTRY']._loaded_options = None
  _globals['_COMMANDMETADATA_PARAMETERMETAENTRY']._serialized_options = b'8\001'
  _globals['_COMMANDMETADATA_TAGSENTRY']._loaded_options = None
  _globals['_COMMANDMETADATA_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_COMMANDREQUEST']._serialized_start=111
  _globals['_COMMANDREQUEST']._serialized_end=319
  _globals['_COMMANDRESPONSE']._serialized_start=321
  _globals['_COMMANDRESPONSE']._serialized_end=427
  _globals['_FILEINFO']._serialized_start=429
  _globals['_FILEINFO']._serialized_end=478
  _globals['_COMMANDSMETADATA']._serialized_start=480
  _globals['_COMMANDSMETADATA']._serialized_end=543
  _globals['_COMMANDMETADATA']._serialized_start=546
  _globals['_COMMANDMETADATA']._serialized_end=916
  _globals['_COMMANDMETADATA_PARAMETERMETAENTRY']._serialized_start=819
  _globals['_COMMANDMETADATA_PARAMETERMETAENTRY']._serialized_end=871
  _globals['_COMMANDMETADATA_TAGSENTRY']._serialized_start=873
  _globals['_COMMANDMETADATA_TAGSENTRY']._serialized_end=916
# @@protoc_insertion_point(module_scope)



from . import Response, Adapter, Any, adapter_controller_post, adapter_controller_delete
from formant.sdk.cloud.v2.src.resources.resources import Resources

class Adapters(Resources):

    def create(self, adapter: Adapter):
        """Creates an Adapter"""
        client = self._get_client()
        response: Response[Adapter] = adapter_controller_post.sync_detailed(client=client, json_body=adapter)
        return response

    async def create_async(self, adapter: Adapter):
        """Creates an Adapter"""
        client = self._get_client()
        response: Response[Adapter] = await adapter_controller_post.asyncio_detailed(client=client, json_body=adapter)
        return response

    def delete(self, id: str):
        """Deletes and Adapter"""
        client = self._get_client()
        response: Response[Any] = adapter_controller_delete.sync_detailed(client=client, id=id)
        return response

    async def delete_async(self, id: str):
        """Deletes and Adapter"""
        client = self._get_client()
        response: Response[Any] = await adapter_controller_delete.asyncio_detailed(client=client, id=id)
        return response


from formant.sdk.cloud.v2.formant_ingest_api_client.models.ingestion_request import IngestionRequest
from formant.sdk.cloud.v2.formant_ingest_api_client.api.ingest import ingest_controller_post, ingest_controller_post_all
from formant.sdk.cloud.v2.formant_ingest_api_client.types import *
from typing import List


from enum import Enum


class SqlQueryAggregateLevel(str, Enum):
    HOUR = "hour"
    DATE = "date"
    DAY = "day"
    WEEK = "week"
    MONTH = "month"
    YEAR = "year"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.image_annotation import ImageAnnotation


T = TypeVar("T", bound="Image")


@attr.s(auto_attribs=True)
class Image:
    """
    Attributes:
        url (str):
        size (Union[Unset, int]):
        annotations (Union[Unset, List['ImageAnnotation']]):
    """

    url: str
    size: Union[Unset, int] = UNSET
    annotations: Union[Unset, List["ImageAnnotation"]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        url = self.url
        size = self.size
        annotations: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.annotations, Unset):
            annotations = []
            for annotations_item_data in self.annotations:
                annotations_item = annotations_item_data.to_dict()

                annotations.append(annotations_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "url": url,
            }
        )
        if size is not UNSET:
            field_dict["size"] = size
        if annotations is not UNSET:
            field_dict["annotations"] = annotations

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.image_annotation import ImageAnnotation

        d = src_dict.copy()
        url = d.pop("url")

        size = d.pop("size", UNSET)

        annotations = []
        _annotations = d.pop("annotations", UNSET)
        for annotations_item_data in _annotations or []:
            annotations_item = ImageAnnotation.from_dict(annotations_item_data)

            annotations.append(annotations_item)

        image = cls(
            url=url,
            size=size,
            annotations=annotations,
        )

        image.additional_properties = d
        return image

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from formant.sdk.cloud.v2.formant_admin_api_client.models import TransformTreeViewConfiguration, Camera, LocationViewConfiguration, PointCloudViewConfiguration, LocationViewConfigurationBasemap, NumericViewConfiguration, PartialViewTags, ViewTags, ViewConfiguration, PartialViewLayoutType, ImageViewConfigurationMode, LocationViewport, ImageViewConfiguration, PartialView, Filter, Location, View, ViewLayoutType, Vector3, LocalizationViewConfiguration, ViewConfigurationType, BitsetViewConfiguration, ViewListResponse
from formant.sdk.cloud.v2.formant_admin_api_client.api.view import view_controller_get_one, view_controller_get_all, view_controller_patch
from formant.sdk.cloud.v2.formant_admin_api_client.types import *


import time
import rospy
from formant.sdk.agent.v1 import Client as FormantClient
from formant.sdk.agent.v1.localization.types import (
    PointCloud,
    Odometry,
    Map,
    Path,
    Goal,
    Transform,
)
from sensor_msgs.msg import PointCloud2 as ROSPointCloud2
from nav_msgs.msg import (
    Odometry as ROSOdometry,
    OccupancyGrid as ROSOccupancyGrid,
    Path as ROSPath,
)
from geometry_msgs.msg import PoseStamped as ROSPoseStamped

POINT_CLOUD_TOPIC = "/scan"
ODOM_TOPIC = "/odom"
MAP_TOPIC = "/map"
PATH_TOPIC = "/move_base/NavfnROS/plan"
GOAL_TOPIC = "/move_base/current_goal"
BASE_REFERENCE_FRAME = "map"


class ROSLocalizationTester:
    def __init__(self):
        self._fclient = FormantClient(
            ignore_throttled=True, ignore_unavailable=True, agent_url="localhost:5501"
        )
        self._localization_manager = self._fclient.get_localization_manager(
            "ros.localization"
        )
        self._subscribers = []
        SUBSCRIBER_MAPPING = [
            (POINT_CLOUD_TOPIC, ROSPointCloud2, self._pointcloud_callback),
            (ODOM_TOPIC, ROSOdometry, self._odometry_callback),
            (MAP_TOPIC, ROSOccupancyGrid, self._map_callback),
            (PATH_TOPIC, ROSPath, self._path_callback),
            (GOAL_TOPIC, ROSPoseStamped, self._goal_callback),
        ]
        for mapping in SUBSCRIBER_MAPPING:
            self._subscribers.append(
                rospy.Subscriber(mapping[0], mapping[1], mapping[2])
            )
        self._tf_buffer = None
        self._tf_listener = None
        self._setup_trasform_listener()

    def _setup_trasform_listener(self):
        try:
            from tf2_ros.buffer import Buffer
            from tf2_ros.transform_listener import TransformListener

            self._tf_buffer = Buffer()
            self._tf_listener = TransformListener(self._tf_buffer)
        except Exception as e:
            print("Error setting up tf2_ros transform listener: %s" % str(e))

    def _lookup_transform(self, msg):
        if self._tf_buffer is None or self._tf_listener is None:
            return Transform()
        try:
            transform = self._tf_buffer.lookup_transform(
                BASE_REFERENCE_FRAME,
                msg.header.frame_id,
                rospy.Time(0),
                rospy.Duration(0.2),
            )
            return Transform.from_ros_transform_stamped(transform)
        except Exception as e:
            print(
                "Error looking up transform between %s and %s: %s, using identity"
                % (BASE_REFERENCE_FRAME, msg.header.frame_id, str(e))
            )
        return Transform()

    def _pointcloud_callback(self, pointcloud):
        print("pointcloud")
        self._generic_callback(
            pointcloud, PointCloud, self._localization_manager.update_point_cloud
        )

    def _odometry_callback(self, odometry):
        self._generic_callback(
            odometry, Odometry, self._localization_manager.update_odometry
        )

    def _map_callback(self, map):
        self._generic_callback(map, Map, self._localization_manager.update_map)

    def _path_callback(self, path):
        print("path")
        self._generic_callback(path, Path, self._localization_manager.update_path)

    def _goal_callback(self, goal):
        print("goal")

        formant_goal = Goal(Transform.from_ros_pose_stamped(goal))
        formant_goal.transform_to_world = self._lookup_transform(goal)
        self._localization_manager.update_goal(formant_goal)

    def _generic_callback(self, obj, formant_type, update_function):
        formant_obj = formant_type.from_ros(obj)
        formant_obj.transform_to_world = self._lookup_transform(obj)
        update_function(formant_obj)


if __name__ == "__main__":
    rospy.init_node("formant_localization_tester")
    ROSLocalizationTester()
    while True:
        time.sleep(1)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="NumericSetEntry")


@attr.s(auto_attribs=True)
class NumericSetEntry:
    """
    Attributes:
        label (str):
        value (float):
        unit (Union[Unset, str]):
    """

    label: str
    value: float
    unit: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        label = self.label
        value = self.value
        unit = self.unit

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "label": label,
                "value": value,
            }
        )
        if unit is not UNSET:
            field_dict["unit"] = unit

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        label = d.pop("label")

        value = d.pop("value")

        unit = d.pop("unit", UNSET)

        numeric_set_entry = cls(
            label=label,
            value=value,
            unit=unit,
        )

        numeric_set_entry.additional_properties = d
        return numeric_set_entry

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import TYPE_CHECKING, Any, Dict, List, Optional, Type, TypeVar

import attr
from dateutil.parser import isoparse

from ..models.device_details_type import DeviceDetailsType

if TYPE_CHECKING:
    from ..models.device_details_tags import DeviceDetailsTags


T = TypeVar("T", bound="DeviceDetails")


@attr.s(auto_attribs=True)
class DeviceDetails:
    """
    Attributes:
        created_at (datetime.datetime):
        updated_at (datetime.datetime):
        id (str):
        name (str):
        type (DeviceDetailsType):
        tags (DeviceDetailsTags):
        enabled (bool):
        public_key (str):
        description (Optional[str]):
        online (Optional[bool]):
        last_seen (Optional[datetime.datetime]):
        agent_version (Optional[str]):
        disabled_at (Optional[datetime.datetime]):
    """

    created_at: datetime.datetime
    updated_at: datetime.datetime
    id: str
    name: str
    type: DeviceDetailsType
    tags: "DeviceDetailsTags"
    enabled: bool
    public_key: str
    description: Optional[str]
    online: Optional[bool]
    last_seen: Optional[datetime.datetime]
    agent_version: Optional[str]
    disabled_at: Optional[datetime.datetime]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        created_at = self.created_at.isoformat()

        updated_at = self.updated_at.isoformat()

        id = self.id
        name = self.name
        type = self.type.value

        tags = self.tags.to_dict()

        enabled = self.enabled
        public_key = self.public_key
        description = self.description
        online = self.online
        last_seen = self.last_seen.isoformat() if self.last_seen else None

        agent_version = self.agent_version
        disabled_at = self.disabled_at.isoformat() if self.disabled_at else None

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "createdAt": created_at,
                "updatedAt": updated_at,
                "id": id,
                "name": name,
                "type": type,
                "tags": tags,
                "enabled": enabled,
                "publicKey": public_key,
                "description": description,
                "online": online,
                "lastSeen": last_seen,
                "agentVersion": agent_version,
                "disabledAt": disabled_at,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.device_details_tags import DeviceDetailsTags

        d = src_dict.copy()
        created_at = isoparse(d.pop("createdAt"))

        updated_at = isoparse(d.pop("updatedAt"))

        id = d.pop("id")

        name = d.pop("name")

        type = DeviceDetailsType(d.pop("type"))

        tags = DeviceDetailsTags.from_dict(d.pop("tags"))

        enabled = d.pop("enabled")

        public_key = d.pop("publicKey")

        description = d.pop("description")

        online = d.pop("online")

        _last_seen = d.pop("lastSeen")
        last_seen: Optional[datetime.datetime]
        if _last_seen is None:
            last_seen = None
        else:
            last_seen = isoparse(_last_seen)

        agent_version = d.pop("agentVersion")

        _disabled_at = d.pop("disabledAt")
        disabled_at: Optional[datetime.datetime]
        if _disabled_at is None:
            disabled_at = None
        else:
            disabled_at = isoparse(_disabled_at)

        device_details = cls(
            created_at=created_at,
            updated_at=updated_at,
            id=id,
            name=name,
            type=type,
            tags=tags,
            enabled=enabled,
            public_key=public_key,
            description=description,
            online=online,
            last_seen=last_seen,
            agent_version=agent_version,
            disabled_at=disabled_at,
        )

        device_details.additional_properties = d
        return device_details

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class DeviceDetailsSortColumn(str, Enum):
    ID = "id"
    NAME = "name"
    TYPE = "type"
    TAGS = "tags"
    ENABLED = "enabled"

    def __str__(self) -> str:
        return str(self.value)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/protoc_gen_swagger/options/annotations.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/protoc_gen_swagger/options/annotations.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from formant.protos.protoc_gen_swagger.options import openapiv2_pb2 as protos_dot_protoc__gen__swagger_dot_options_dot_openapiv2__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3protos/protoc_gen_swagger/options/annotations.proto\x12\'grpc.gateway.protoc_gen_swagger.options\x1a\x31protos/protoc_gen_swagger/options/openapiv2.proto\x1a google/protobuf/descriptor.proto:j\n\x11openapiv2_swagger\x12\x1c.google.protobuf.FileOptions\x18\x92\x08 \x01(\x0b\x32\x30.grpc.gateway.protoc_gen_swagger.options.Swagger:p\n\x13openapiv2_operation\x12\x1e.google.protobuf.MethodOptions\x18\x92\x08 \x01(\x0b\x32\x32.grpc.gateway.protoc_gen_swagger.options.Operation:k\n\x10openapiv2_schema\x12\x1f.google.protobuf.MessageOptions\x18\x92\x08 \x01(\x0b\x32/.grpc.gateway.protoc_gen_swagger.options.Schema:e\n\ropenapiv2_tag\x12\x1f.google.protobuf.ServiceOptions\x18\x92\x08 \x01(\x0b\x32,.grpc.gateway.protoc_gen_swagger.options.Tag:l\n\x0fopenapiv2_field\x12\x1d.google.protobuf.FieldOptions\x18\x92\x08 \x01(\x0b\x32\x33.grpc.gateway.protoc_gen_swagger.options.JSONSchemaBCZAgithub.com/grpc-ecosystem/grpc-gateway/protoc-gen-swagger/optionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.protoc_gen_swagger.options.annotations_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/grpc-ecosystem/grpc-gateway/protoc-gen-swagger/options'
# @@protoc_insertion_point(module_scope)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

from ..models.stream_data_type import StreamDataType

if TYPE_CHECKING:
    from ..models.stream_data_points_item import StreamDataPointsItem
    from ..models.stream_data_tags import StreamDataTags


T = TypeVar("T", bound="StreamData")


@attr.s(auto_attribs=True)
class StreamData:
    """
    Attributes:
        name (str):
        device_id (str):
        tags (StreamDataTags):
        type (StreamDataType):
        points (List['StreamDataPointsItem']):
    """

    name: str
    device_id: str
    tags: "StreamDataTags"
    type: StreamDataType
    points: List["StreamDataPointsItem"]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        device_id = self.device_id
        tags = self.tags.to_dict()

        type = self.type.value

        points = []
        for points_item_data in self.points:
            points_item = points_item_data.to_dict()

            points.append(points_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "deviceId": device_id,
                "tags": tags,
                "type": type,
                "points": points,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.stream_data_points_item import StreamDataPointsItem
        from ..models.stream_data_tags import StreamDataTags

        d = src_dict.copy()
        name = d.pop("name")

        device_id = d.pop("deviceId")

        tags = StreamDataTags.from_dict(d.pop("tags"))

        type = StreamDataType(d.pop("type"))

        points = []
        _points = d.pop("points")
        for points_item_data in _points:
            points_item = StreamDataPointsItem.from_dict(
                type=type, raw_data=points_item_data
            )

            points.append(points_item)

        stream_data = cls(
            name=name,
            device_id=device_id,
            tags=tags,
            type=type,
            points=points,
        )

        stream_data.additional_properties = d
        return stream_data

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class OrganizationFlagsItem(str, Enum):
    SETTINGS_ROLE = "settings.role"
    SETTINGS_USER = "settings.user"
    SETTINGS_DEVICE = "settings.device"
    SETTINGS_TEAM = "settings.team"
    SETTINGS_GROUP = "settings.group"
    SETTINGS_CONFIG_TEMPLATE = "settings.config_template"
    SETTINGS_EVENT = "settings.event"
    SETTINGS_VIEW = "settings.view"
    SETTINGS_COMMAND = "settings.command"
    SETTINGS_SCHEDULE = "settings.schedule"
    SETTINGS_ANNOTATION = "settings.annotation"
    SETTINGS_SHARE = "settings.share"
    SETTINGS_STREAM = "settings.stream"
    SETTINGS_TAG = "settings.tag"
    SETTINGS_INTEGRATION = "settings.integration"
    SETTINGS_FILE_STORAGE = "settings.file_storage"
    SETTINGS_ADAPTER = "settings.adapter"
    SETTINGS_MODULE = "settings.module"
    SETTINGS_ORGANIZATION = "settings.organization"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.filter_ import Filter
    from ..models.partial_command_template_parameter_meta import PartialCommandTemplateParameterMeta
    from ..models.partial_command_template_tags import PartialCommandTemplateTags
    from ..models.scope_filter import ScopeFilter


T = TypeVar("T", bound="PartialCommandTemplate")


@attr.s(auto_attribs=True)
class PartialCommandTemplate:
    """
    Attributes:
        organization_id (Union[Unset, str]): ID for the organization in which you want to create this new command
            template.
        name (Union[Unset, str]): Name of this command template.
        command (Union[Unset, str]): Function, script, or routine that will be executed by a command in this template.
        description (Union[Unset, str]): Description of this command template.
        parameter_enabled (Union[Unset, bool]): If you want to send parameters with your command, set this to `true`.
        allow_parameter_override (Union[Unset, bool]):
        parameter_value (Union[Unset, str]): This string will be passed as a parameter when this command is sent.
        parameter_meta (Union[Unset, PartialCommandTemplateParameterMeta]): You can use this to add many parameters in a
            more structured way.
        device_scope (Union[Unset, None, ScopeFilter]):
        enabled (Union[Unset, bool]): If set to `false`, this command template will be deleted.
        device_filter (Union[Unset, None, Filter]):
        id (Union[Unset, str]):
        created_at (Union[Unset, datetime.datetime]):
        updated_at (Union[Unset, datetime.datetime]):
        tags (Union[Unset, PartialCommandTemplateTags]):
    """

    organization_id: Union[Unset, str] = UNSET
    name: Union[Unset, str] = UNSET
    command: Union[Unset, str] = UNSET
    description: Union[Unset, str] = UNSET
    parameter_enabled: Union[Unset, bool] = UNSET
    allow_parameter_override: Union[Unset, bool] = UNSET
    parameter_value: Union[Unset, str] = UNSET
    parameter_meta: Union[Unset, "PartialCommandTemplateParameterMeta"] = UNSET
    device_scope: Union[Unset, None, "ScopeFilter"] = UNSET
    enabled: Union[Unset, bool] = UNSET
    device_filter: Union[Unset, None, "Filter"] = UNSET
    id: Union[Unset, str] = UNSET
    created_at: Union[Unset, datetime.datetime] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET
    tags: Union[Unset, "PartialCommandTemplateTags"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        organization_id = self.organization_id
        name = self.name
        command = self.command
        description = self.description
        parameter_enabled = self.parameter_enabled
        allow_parameter_override = self.allow_parameter_override
        parameter_value = self.parameter_value
        parameter_meta: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.parameter_meta, Unset):
            parameter_meta = self.parameter_meta.to_dict()

        device_scope: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.device_scope, Unset):
            device_scope = self.device_scope.to_dict() if self.device_scope else None

        enabled = self.enabled
        device_filter: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.device_filter, Unset):
            device_filter = self.device_filter.to_dict() if self.device_filter else None

        id = self.id
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        tags: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if name is not UNSET:
            field_dict["name"] = name
        if command is not UNSET:
            field_dict["command"] = command
        if description is not UNSET:
            field_dict["description"] = description
        if parameter_enabled is not UNSET:
            field_dict["parameterEnabled"] = parameter_enabled
        if allow_parameter_override is not UNSET:
            field_dict["allowParameterOverride"] = allow_parameter_override
        if parameter_value is not UNSET:
            field_dict["parameterValue"] = parameter_value
        if parameter_meta is not UNSET:
            field_dict["parameterMeta"] = parameter_meta
        if device_scope is not UNSET:
            field_dict["deviceScope"] = device_scope
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if device_filter is not UNSET:
            field_dict["deviceFilter"] = device_filter
        if id is not UNSET:
            field_dict["id"] = id
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at
        if tags is not UNSET:
            field_dict["tags"] = tags

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.filter_ import Filter
        from ..models.partial_command_template_parameter_meta import PartialCommandTemplateParameterMeta
        from ..models.partial_command_template_tags import PartialCommandTemplateTags
        from ..models.scope_filter import ScopeFilter

        d = src_dict.copy()
        organization_id = d.pop("organizationId", UNSET)

        name = d.pop("name", UNSET)

        command = d.pop("command", UNSET)

        description = d.pop("description", UNSET)

        parameter_enabled = d.pop("parameterEnabled", UNSET)

        allow_parameter_override = d.pop("allowParameterOverride", UNSET)

        parameter_value = d.pop("parameterValue", UNSET)

        _parameter_meta = d.pop("parameterMeta", UNSET)
        parameter_meta: Union[Unset, PartialCommandTemplateParameterMeta]
        if isinstance(_parameter_meta, Unset):
            parameter_meta = UNSET
        else:
            parameter_meta = PartialCommandTemplateParameterMeta.from_dict(_parameter_meta)

        _device_scope = d.pop("deviceScope", UNSET)
        device_scope: Union[Unset, None, ScopeFilter]
        if _device_scope is None:
            device_scope = None
        elif isinstance(_device_scope, Unset):
            device_scope = UNSET
        else:
            device_scope = ScopeFilter.from_dict(_device_scope)

        enabled = d.pop("enabled", UNSET)

        _device_filter = d.pop("deviceFilter", UNSET)
        device_filter: Union[Unset, None, Filter]
        if _device_filter is None:
            device_filter = None
        elif isinstance(_device_filter, Unset):
            device_filter = UNSET
        else:
            device_filter = Filter.from_dict(_device_filter)

        id = d.pop("id", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        _tags = d.pop("tags", UNSET)
        tags: Union[Unset, PartialCommandTemplateTags]
        if isinstance(_tags, Unset):
            tags = UNSET
        else:
            tags = PartialCommandTemplateTags.from_dict(_tags)

        partial_command_template = cls(
            organization_id=organization_id,
            name=name,
            command=command,
            description=description,
            parameter_enabled=parameter_enabled,
            allow_parameter_override=allow_parameter_override,
            parameter_value=parameter_value,
            parameter_meta=parameter_meta,
            device_scope=device_scope,
            enabled=enabled,
            device_filter=device_filter,
            id=id,
            created_at=created_at,
            updated_at=updated_at,
            tags=tags,
        )

        partial_command_template.additional_properties = d
        return partial_command_template

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import unittest
from formant.sdk.cloud.v2.src.query_api import QueryAPI
from formant.sdk.cloud.v2.formant_query_api_client.models.scope_filter import (
    ScopeFilter,
)
import dateutil.parser as parser
import os

EMAIL = os.getenv("FORMANT_EMAIL")
PASSWORD = os.getenv("FORMANT_PASSWORD")
BASE_URL = "https://api.formant.io/v1"


class TestMetadata(unittest.TestCase):
    def __init__(self, *args, **kwargs):
        super(TestMetadata, self).__init__(*args, **kwargs)
        self.client = QueryAPI(email=EMAIL, password=PASSWORD, base_url=BASE_URL)

    def test_list_metadata(self):
        start = parser.isoparse("2022-12-11T02:00:00.000Z")
        end = parser.isoparse("2022-12-11T02:02:00.000Z")
        scope_filter = ScopeFilter(start=start, end=end)

        response = self.client.metadata.list_metadata(scope_filter)
        self.assertEqual(response.status_code, 200)

    def test_list_stream_names(self):
        start = parser.isoparse("2022-12-11T02:00:00.000Z")
        end = parser.isoparse("2022-12-11T02:02:00.000Z")
        scope_filter = ScopeFilter(start=start, end=end)

        response = self.client.metadata.list_stream_names(scope_filter)
        self.assertEqual(response.status_code, 200)

    def test_devices_ids(self):
        start = parser.isoparse("2022-12-11T02:00:00.000Z")
        end = parser.isoparse("2022-12-11T02:02:00.000Z")
        scope_filter = ScopeFilter(start=start, end=end)

        response = self.client.metadata.list_device_ids(scope_filter)
        self.assertEqual(response.status_code, 200)


unittest.main()



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="BitsetViewConfiguration")


@attr.s(auto_attribs=True)
class BitsetViewConfiguration:
    """
    Attributes:
        split_by_key (Union[Unset, str]):
        column_width (Union[Unset, int]):
    """

    split_by_key: Union[Unset, str] = UNSET
    column_width: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        split_by_key = self.split_by_key
        column_width = self.column_width

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if split_by_key is not UNSET:
            field_dict["splitByKey"] = split_by_key
        if column_width is not UNSET:
            field_dict["columnWidth"] = column_width

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        split_by_key = d.pop("splitByKey", UNSET)

        column_width = d.pop("columnWidth", UNSET)

        bitset_view_configuration = cls(
            split_by_key=split_by_key,
            column_width=column_width,
        )

        bitset_view_configuration.additional_properties = d
        return bitset_view_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from . import Response, IngestionRequest, List, ingest_controller_post, ingest_controller_post_all
from formant.sdk.cloud.v2.src.resources.resources import Resources

class Ingest(Resources):

    def post(self, ingestion_request: IngestionRequest):
        client = self._get_client()
        response: Response = ingest_controller_post.sync_detailed(client=client, json_body=ingestion_request)
        return response

    async def post_async(self, ingestion_request: IngestionRequest):
        client = self._get_client()
        response: Response = await ingest_controller_post.asyncio_detailed(client=client, json_body=ingestion_request)
        return response

    def post_all(self, ingestion_requests: List[IngestionRequest]):
        client = self._get_client()
        response: Response = ingest_controller_post_all.sync_detailed(client=client, json_body=ingestion_requests)
        return response

    async def post_all_async(self, ingestion_requests: List[IngestionRequest]):
        client = self._get_client()
        response: Response = await ingest_controller_post_all.asyncio_detailed(client=client, json_body=ingestion_requests)
        return response


from formant.sdk.cloud.v2.formant_admin_api_client.models import DeviceTags, DeviceStreamRosTransformTreeConfigurationRosVersion, DeviceStreamRosTransformTreeConfigurationType, DeviceTeleopCustomStreamConfigurationMode, DeviceTeleopCustomStreamConfigurationNumericControlVisualization, DeviceTeleopRosStreamConfiguration, DeviceTeleopRosStreamConfigurationMode, KernelInfo, DeviceFollower, OnvifDevice, DeviceTeleopCustomStreamConfiguration, DeviceStreamConfigurationQuality, OnDemandPresenceStreamItemGroupDatapointType, DeviceDetailsTags, DeviceConfigurationTemplate, DeviceStreamRosTopicConfigurationType, DeviceType, DeviceOnlineEventMetadata, DeviceDetails, DeviceOnlineEventStreamType, AudioDevice, ScopeFilterTypesItem, OnDemandState, DeviceStreamHardwareConfigurationType, DeviceOfflineEventSeverity, DeviceTeleopHardwareStreamConfigurationHardwareType, DeviceApplicationConfiguration, VideoDevice, RtcInfoRtcIceTransportPoliciesItem, DeviceStreamConfiguration, DeviceStreamCustomConfiguration, OnDemandPresenceTimeRange, DeviceTeleopHardwareStreamConfigurationMode, DeviceDetailsSort, OnDemandBufferBufferType, DeviceStreamTransformConfiguration, RtcInfoRtcIceServerProtocol, DeviceStreamHardwareConfigurationHardwareType, TeleopJoystickConfiguration, DeviceTeleopRosStreamConfigurationTopicType, TeleopJoystickAxisConfigurationDimension, DeviceTeleopConfiguration, DeviceOnlineEvent, DeviceStreamDirectoryWatchConfiguration, DeviceOnlineEventSeverity, DeviceConfigurationTemplateListResponse, DeviceTeleopHardwareStreamConfiguration, DeviceStateEnv, DeviceProvisioning, DeviceStreamFileTailConfigurationFileFormat, DeviceRosConfiguration, DeviceStreamDirectoryWatchConfigurationFileType, PartialDeviceTags, DeviceRealtimeConfiguration, ScopeFilter, DeviceConfigurationTemplateTags, DeviceState, DeviceConfiguration, DeviceRosState, DeviceTeleopCustomStreamConfigurationRtcStreamType, DevicePortForwardingConfiguration, DeviceDetailsType, DeviceTelemetryConfiguration, DeviceBlobData, DeviceListResponse, OnDemandStreamPresence, PartialDeviceType, DeviceOfflineEventTags, DeviceReportedConfigurationState, TeleopJoystickConfigurationPosition, NodeInfo, DeviceScope, DeviceOnlineEventTags, DeviceTeleopRosStreamConfigurationNumericControlVisualization, DeviceDetailsSortColumn, DeviceCredentials, TeleopJoystickAxisConfiguration, DeviceOfflineEvent, DeviceConfigurationDocumentTags, DeviceDiskConfiguration, DeviceStreamRosLocalizationConfigurationRosVersion, DeviceOnlineEventType, NetworkInfo, OsInfo, DeviceStreamRosLocalizationConfiguration, DeviceResourcesConfiguration, DeviceStreamDirectoryWatchConfigurationType, HwInfo, DeviceStreamRosLocalizationConfigurationType, PartialDevice, DeviceStreamRosTopicConfigurationRosVersion, TeleopViewConfiguration, DeviceScopeTypesItem, DeviceStreamConfigurationTags, DeviceStreamHardwareConfiguration, DeviceStreamCustomConfigurationType, DeviceQuery, OnDemandPresenceStreamItemGroup, AdapterConfiguration, DeviceApplicationConfigurationConfigurationMap, DeviceOfflineEventType, DeviceOfflineEventMetadata, DeviceDetailsSortOrder, DeviceOfflineEventStreamType, DeviceProvisioningRequest, DeviceStreamRosTransformTreeConfiguration, DeviceTeleopRosStreamConfigurationRosVersion, DeviceStreamFileTailConfiguration, DeviceTeleopRosStreamConfigurationQuality, Network, RosTopic, CommandProgress, DeviceTeleopRosStreamConfigurationAudioCodec, DeviceQueryType, DeviceTeleopHardwareStreamConfigurationQuality, DeviceConfigurationDocument, DeviceDetailsListResponse, RtcInfo, Device, DeviceStreamRosTopicConfiguration, DeviceStreamHardwareConfigurationQuality, DeviceDiagnosticsConfiguration, OnDemandBuffer, ValidationConfiguration, DeviceTeleopCustomStreamConfigurationQuality, DeviceTeleopHardwareStreamConfigurationRtcStreamType, DeviceStreamFileTailConfigurationType
from formant.sdk.cloud.v2.formant_admin_api_client.api.device import device_controller_query, device_controller_patch, device_controller_get_one, device_controller_get_configuration, device_controller_post_configuration
from formant.sdk.cloud.v2.formant_admin_api_client.types import *
from formant.sdk.cloud.v2.formant_admin_api_client.types import Optional


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/model/v1/media.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/model/v1/media.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from formant.protos.model.v1 import math_pb2 as protos_dot_model_dot_v1_dot_math__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bprotos/model/v1/media.proto\x12\x08v1.model\x1a\x1aprotos/model/v1/math.proto\"C\n\x05Image\x12\x14\n\x0c\x63ontent_type\x18\x01 \x01(\t\x12\r\n\x03url\x18\x02 \x01(\tH\x00\x12\r\n\x03raw\x18\x03 \x01(\x0cH\x00\x42\x06\n\x04\x64\x61ta\"m\n\nPointCloud\x12\x0c\n\x04uuid\x18\x04 \x01(\t\x12\r\n\x03url\x18\x01 \x01(\tH\x00\x12\r\n\x03raw\x18\x02 \x01(\x0cH\x00\x12+\n\x0eworld_to_local\x18\x03 \x01(\x0b\x32\x13.v1.model.TransformB\x06\n\x04\x64\x61ta\"J\n\rRtcPointCloud\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12+\n\x0eworld_to_local\x18\x02 \x01(\x0b\x32\x13.v1.model.Transform\"B\n\x0eH264VideoFrame\x12\r\n\x05index\x18\x01 \x01(\x05\x12\r\n\x05\x66lags\x18\x02 \x01(\x05\x12\x12\n\nframe_data\x18\x03 \x01(\x0c\"?\n\nAudioChunk\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x12\n\nchunk_data\x18\x03 \x01(\x0c\"R\n\x05Video\x12\x11\n\tmime_type\x18\x01 \x01(\t\x12\x10\n\x08\x64uration\x18\x02 \x01(\x03\x12\r\n\x03url\x18\x03 \x01(\tH\x00\x12\r\n\x03raw\x18\x04 \x01(\x0cH\x00\x42\x06\n\x04\x64\x61ta\"5\n\rTransformTree\x12\r\n\x03url\x18\x01 \x01(\tH\x00\x12\r\n\x03raw\x18\x02 \x01(\x0cH\x00\x42\x06\n\x04\x64\x61taB+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.model.v1.media_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/model'
  _globals['_IMAGE']._serialized_start=69
  _globals['_IMAGE']._serialized_end=136
  _globals['_POINTCLOUD']._serialized_start=138
  _globals['_POINTCLOUD']._serialized_end=247
  _globals['_RTCPOINTCLOUD']._serialized_start=249
  _globals['_RTCPOINTCLOUD']._serialized_end=323
  _globals['_H264VIDEOFRAME']._serialized_start=325
  _globals['_H264VIDEOFRAME']._serialized_end=391
  _globals['_AUDIOCHUNK']._serialized_start=393
  _globals['_AUDIOCHUNK']._serialized_end=456
  _globals['_VIDEO']._serialized_start=458
  _globals['_VIDEO']._serialized_end=540
  _globals['_TRANSFORMTREE']._serialized_start=542
  _globals['_TRANSFORMTREE']._serialized_end=595
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from formant.protos.agent.v1 import agent_pb2 as protos_dot_agent_dot_v1_dot_agent__pb2
from formant.protos.model.v1 import datapoint_pb2 as protos_dot_model_dot_v1_dot_datapoint__pb2
from formant.protos.model.v1 import intervention_pb2 as protos_dot_model_dot_v1_dot_intervention__pb2
from formant.protos.model.v1 import math_pb2 as protos_dot_model_dot_v1_dot_math__pb2

GRPC_GENERATED_VERSION = '1.69.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in protos/agent/v1/agent_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class AgentStub(object):
    """Agent is the Formant Agent gRPC API. 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamData = channel.stream_unary(
                '/v1.agent.Agent/StreamData',
                request_serializer=protos_dot_model_dot_v1_dot_datapoint__pb2.Datapoint.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.StreamDataResponse.FromString,
                _registered_method=True)
        self.PostData = channel.unary_unary(
                '/v1.agent.Agent/PostData',
                request_serializer=protos_dot_model_dot_v1_dot_datapoint__pb2.Datapoint.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostDataResponse.FromString,
                _registered_method=True)
        self.PostDataMulti = channel.unary_unary(
                '/v1.agent.Agent/PostDataMulti',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostDataMultiRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostDataMultiResponse.FromString,
                _registered_method=True)
        self.GetTeleopControlDataStream = channel.unary_stream(
                '/v1.agent.Agent/GetTeleopControlDataStream',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopControlDataStreamRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopControlDataStreamResponse.FromString,
                _registered_method=True)
        self.GetTeleopHeartbeatStream = channel.unary_stream(
                '/v1.agent.Agent/GetTeleopHeartbeatStream',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopHeartbeatStreamRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopHeartbeatStreamResponse.FromString,
                _registered_method=True)
        self.GetTelemetryListenerStream = channel.unary_stream(
                '/v1.agent.Agent/GetTelemetryListenerStream',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTelemetryListenerStreamRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTelemetryListenerStreamResponse.FromString,
                _registered_method=True)
        self.GetCustomDataChannelMessageStream = channel.unary_stream(
                '/v1.agent.Agent/GetCustomDataChannelMessageStream',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCustomDataChannelMessageStreamRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCustomDataChannelMessageStreamResponse.FromString,
                _registered_method=True)
        self.CreateEvent = channel.unary_unary(
                '/v1.agent.Agent/CreateEvent',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.CreateEventRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.CreateEventResponse.FromString,
                _registered_method=True)
        self.CreateInterventionRequest = channel.unary_unary(
                '/v1.agent.Agent/CreateInterventionRequest',
                request_serializer=protos_dot_model_dot_v1_dot_intervention__pb2.InterventionRequest.SerializeToString,
                response_deserializer=protos_dot_model_dot_v1_dot_intervention__pb2.InterventionRequest.FromString,
                _registered_method=True)
        self.GetInterventionRequest = channel.unary_unary(
                '/v1.agent.Agent/GetInterventionRequest',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetInterventionRequestRequest.SerializeToString,
                response_deserializer=protos_dot_model_dot_v1_dot_intervention__pb2.InterventionRequest.FromString,
                _registered_method=True)
        self.GetInterventionResponse = channel.unary_unary(
                '/v1.agent.Agent/GetInterventionResponse',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetInterventionResponseRequest.SerializeToString,
                response_deserializer=protos_dot_model_dot_v1_dot_intervention__pb2.InterventionResponse.FromString,
                _registered_method=True)
        self.GetStreamsConfiguration = channel.unary_unary(
                '/v1.agent.Agent/GetStreamsConfiguration',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetStreamsConfigurationRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetStreamsConfigurationResponse.FromString,
                _registered_method=True)
        self.GetApplicationConfiguration = channel.unary_unary(
                '/v1.agent.Agent/GetApplicationConfiguration',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetApplicationConfigurationRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetApplicationConfigurationResponse.FromString,
                _registered_method=True)
        self.GetConfigBlobData = channel.unary_unary(
                '/v1.agent.Agent/GetConfigBlobData',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetConfigBlobDataRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetConfigBlobDataResponse.FromString,
                _registered_method=True)
        self.GetAgentConfiguration = channel.unary_unary(
                '/v1.agent.Agent/GetAgentConfiguration',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetAgentConfigurationRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetAgentConfigurationResponse.FromString,
                _registered_method=True)
        self.GetBufferMetadata = channel.unary_unary(
                '/v1.agent.Agent/GetBufferMetadata',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetBufferMetadataRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetBufferMetadataResponse.FromString,
                _registered_method=True)
        self.QueryDatapoints = channel.unary_unary(
                '/v1.agent.Agent/QueryDatapoints',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.QueryDatapointsRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.QueryDatapointsResponse.FromString,
                _registered_method=True)
        self.QueryEvents = channel.unary_unary(
                '/v1.agent.Agent/QueryEvents',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.QueryEventsRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.QueryEventsResponse.FromString,
                _registered_method=True)
        self.Health = channel.unary_unary(
                '/v1.agent.Agent/Health',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.HealthRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.HealthResponse.FromString,
                _registered_method=True)
        self.GetCommandRequest = channel.unary_unary(
                '/v1.agent.Agent/GetCommandRequest',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestResponse.FromString,
                _registered_method=True)
        self.GetCommandRequestStream = channel.unary_stream(
                '/v1.agent.Agent/GetCommandRequestStream',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestStreamRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestStreamResponse.FromString,
                _registered_method=True)
        self.SendCommandResponse = channel.unary_unary(
                '/v1.agent.Agent/SendCommandResponse',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.SendCommandResponseRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.SendCommandResponseResponse.FromString,
                _registered_method=True)
        self.PostTransformFrame = channel.unary_unary(
                '/v1.agent.Agent/PostTransformFrame',
                request_serializer=protos_dot_model_dot_v1_dot_math__pb2.TransformFrame.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostTransformFrameResponse.FromString,
                _registered_method=True)
        self.SetBaseFrameID = channel.unary_unary(
                '/v1.agent.Agent/SetBaseFrameID',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.SetBaseFrameIDRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.SetBaseFrameIDResponse.FromString,
                _registered_method=True)
        self.ClearTransformTree = channel.unary_unary(
                '/v1.agent.Agent/ClearTransformTree',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.ClearTransformTreeRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.ClearTransformTreeResponse.FromString,
                _registered_method=True)
        self.GetTeleopInfo = channel.unary_unary(
                '/v1.agent.Agent/GetTeleopInfo',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopInfoRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopInfoResponse.FromString,
                _registered_method=True)
        self.PostLanRtcOffer = channel.unary_unary(
                '/v1.agent.Agent/PostLanRtcOffer',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostLanRtcOfferRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostLanRtcOfferResponse.FromString,
                _registered_method=True)
        self.SendOnCustomDataChannel = channel.unary_unary(
                '/v1.agent.Agent/SendOnCustomDataChannel',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.SendOnCustomDataChannelRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.SendOnCustomDataChannelResponse.FromString,
                _registered_method=True)
        self.PostGenericAPIRequest = channel.unary_unary(
                '/v1.agent.Agent/PostGenericAPIRequest',
                request_serializer=protos_dot_model_dot_v1_dot_datapoint__pb2.GenericAPIDatapoint.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostGenericAPIRequestResponse.FromString,
                _registered_method=True)
        self.PostGenericAPIUnbufferedRequest = channel.unary_unary(
                '/v1.agent.Agent/PostGenericAPIUnbufferedRequest',
                request_serializer=protos_dot_model_dot_v1_dot_datapoint__pb2.GenericAPIDatapoint.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostGenericAPIUnbufferedRequestResponse.FromString,
                _registered_method=True)


class AgentServicer(object):
    """Agent is the Formant Agent gRPC API. 
    """

    def StreamData(self, request_iterator, context):
        """StreamData accepts a stream of data points. See PostData for information on
        expected error conditions and codes. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PostData(self, request, context):
        """PostData accepts a single data point per invocation. An OK status code will
        be returned if the data point was accepted and queued for uploading to the
        Formant cloud. PostData will return an InvalidArgument status code if the
        data point is malformed or has more than 10 tags attached. A
        ResourceExhausted code will be returned if the data point was throttled. An
        Unavailable code will be returned if the Agent is in the process of
        shutting down. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PostDataMulti(self, request, context):
        """PostDataMulti accepts an array of datapoints per invocation. An OK status
        code indicates that all datapoints were accepted and queued for uploading
        to the Formant cloud. If certain datapoints failed or were throttled the
        response will include the index of those datapoints as well as the reason
        for failure. All documentation that applies to PostData also applies to
        this RPC. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTeleopControlDataStream(self, request, context):
        """GetTeleopControlDataStream returns a stream of datapoints sent to this device as
        they arrive from Formant teleop. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTeleopHeartbeatStream(self, request, context):
        """GetTeleopHeartbeatStream returns a stream of GetTeleopHeartbeatStreamResponse
        as heartbeat messages arrive from Formant teleop. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTelemetryListenerStream(self, request, context):
        """GetTelemetryListenerStream returns a stream of telemetry datapoints that have been posted
        to this agent as they arrive, pre-throttling. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCustomDataChannelMessageStream(self, request, context):
        """GetCustomDataChannelMessageStream returns a stream of messages
        received on custom data channels 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEvent(self, request, context):
        """CreateEvent creates a custom event. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateInterventionRequest(self, request, context):
        """CreateInterventionRequest creates an intervention request. The returned
        InterventionRequest's 'id' field will be populated if the call succeeds. An
        Unavailable status code will be returned if an upstream network error
        occurs while trying to create the request. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInterventionRequest(self, request, context):
        """GetInterventionRequest returns an existing InterventionRequest. The
        InterventionRequest's 'responses' field will be empty if an operator has
        yet to respond. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInterventionResponse(self, request, context):
        """GetInterventionResponse returns the first InterventionResponse for the
        provided intervention request. This RPC blocks until an
        InterventionResponse is available to be returned. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStreamsConfiguration(self, request, context):
        """GetStreamsConfiguration returns the configured streams. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetApplicationConfiguration(self, request, context):
        """GetApplicationConfiguration returns application (user-defined)
        configuration data. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConfigBlobData(self, request, context):
        """GetConfigBlobData returns user-defined blob data 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAgentConfiguration(self, request, context):
        """GetAgentConfiguration returns the Agent configuration. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBufferMetadata(self, request, context):
        """GetBufferMetadata returns the metadata for the webRTC buffer. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryDatapoints(self, request, context):
        """QueryDatapoints returns datapoints matching the specified parameters 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryEvents(self, request, context):
        """QueryEvents returns events matching the specified parameters 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Health(self, request, context):
        """Health can be used to check if the Agent is running and its gRPC API is
        available. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCommandRequest(self, request, context):
        """GetCommandRequest returns the latest pending command request. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCommandRequestStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendCommandResponse(self, request, context):
        """SendCommandResponse sends a response to a command request. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PostTransformFrame(self, request, context):
        """PostTransformFrame posts a transform between a parent and child. This
        updates a transform tree within the agent. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetBaseFrameID(self, request, context):
        """SetBaseFrameID sets the base frame Id to be used for transform
        visualizations. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearTransformTree(self, request, context):
        """ClearTransformTree clears the entire TransformTree graph stored in the
        agent. This maintains the base frame id as the root of the graph. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTeleopInfo(self, request, context):
        """GetTeleopInfo returns info on how many active teleop connections there are 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PostLanRtcOffer(self, request, context):
        """PostLanRtcOffer takes a JSON-encoded WebRTC offer and returns a JSON-encoded answer that can be used
        to establish a LAN real-time session. The answering side (agent) will not use ICE candidates,
        so this can only be used to establish a LAN connection. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendOnCustomDataChannel(self, request, context):
        """SendOnCustomDataChannel sends the provided payload on the given custom data channel name,
        if the channel exists. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PostGenericAPIRequest(self, request, context):
        """PostGenericAPIRequest posts a generic API request to the Formant cloud, with the option of injecting Formant authentication 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PostGenericAPIUnbufferedRequest(self, request, context):
        """PostGenericAPIUnbufferedRequest posts a generic API request to the Formant cloud, with the option of injecting Formant authentication.
        This method also returns a response from the Formant cloud to the user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AgentServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StreamData': grpc.stream_unary_rpc_method_handler(
                    servicer.StreamData,
                    request_deserializer=protos_dot_model_dot_v1_dot_datapoint__pb2.Datapoint.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.StreamDataResponse.SerializeToString,
            ),
            'PostData': grpc.unary_unary_rpc_method_handler(
                    servicer.PostData,
                    request_deserializer=protos_dot_model_dot_v1_dot_datapoint__pb2.Datapoint.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostDataResponse.SerializeToString,
            ),
            'PostDataMulti': grpc.unary_unary_rpc_method_handler(
                    servicer.PostDataMulti,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostDataMultiRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostDataMultiResponse.SerializeToString,
            ),
            'GetTeleopControlDataStream': grpc.unary_stream_rpc_method_handler(
                    servicer.GetTeleopControlDataStream,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopControlDataStreamRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopControlDataStreamResponse.SerializeToString,
            ),
            'GetTeleopHeartbeatStream': grpc.unary_stream_rpc_method_handler(
                    servicer.GetTeleopHeartbeatStream,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopHeartbeatStreamRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopHeartbeatStreamResponse.SerializeToString,
            ),
            'GetTelemetryListenerStream': grpc.unary_stream_rpc_method_handler(
                    servicer.GetTelemetryListenerStream,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTelemetryListenerStreamRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTelemetryListenerStreamResponse.SerializeToString,
            ),
            'GetCustomDataChannelMessageStream': grpc.unary_stream_rpc_method_handler(
                    servicer.GetCustomDataChannelMessageStream,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCustomDataChannelMessageStreamRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCustomDataChannelMessageStreamResponse.SerializeToString,
            ),
            'CreateEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEvent,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.CreateEventRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.CreateEventResponse.SerializeToString,
            ),
            'CreateInterventionRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateInterventionRequest,
                    request_deserializer=protos_dot_model_dot_v1_dot_intervention__pb2.InterventionRequest.FromString,
                    response_serializer=protos_dot_model_dot_v1_dot_intervention__pb2.InterventionRequest.SerializeToString,
            ),
            'GetInterventionRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInterventionRequest,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetInterventionRequestRequest.FromString,
                    response_serializer=protos_dot_model_dot_v1_dot_intervention__pb2.InterventionRequest.SerializeToString,
            ),
            'GetInterventionResponse': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInterventionResponse,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetInterventionResponseRequest.FromString,
                    response_serializer=protos_dot_model_dot_v1_dot_intervention__pb2.InterventionResponse.SerializeToString,
            ),
            'GetStreamsConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStreamsConfiguration,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetStreamsConfigurationRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetStreamsConfigurationResponse.SerializeToString,
            ),
            'GetApplicationConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetApplicationConfiguration,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetApplicationConfigurationRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetApplicationConfigurationResponse.SerializeToString,
            ),
            'GetConfigBlobData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConfigBlobData,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetConfigBlobDataRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetConfigBlobDataResponse.SerializeToString,
            ),
            'GetAgentConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAgentConfiguration,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetAgentConfigurationRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetAgentConfigurationResponse.SerializeToString,
            ),
            'GetBufferMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBufferMetadata,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetBufferMetadataRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetBufferMetadataResponse.SerializeToString,
            ),
            'QueryDatapoints': grpc.unary_unary_rpc_method_handler(
                    servicer.QueryDatapoints,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.QueryDatapointsRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.QueryDatapointsResponse.SerializeToString,
            ),
            'QueryEvents': grpc.unary_unary_rpc_method_handler(
                    servicer.QueryEvents,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.QueryEventsRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.QueryEventsResponse.SerializeToString,
            ),
            'Health': grpc.unary_unary_rpc_method_handler(
                    servicer.Health,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.HealthRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.HealthResponse.SerializeToString,
            ),
            'GetCommandRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCommandRequest,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestResponse.SerializeToString,
            ),
            'GetCommandRequestStream': grpc.unary_stream_rpc_method_handler(
                    servicer.GetCommandRequestStream,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestStreamRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestStreamResponse.SerializeToString,
            ),
            'SendCommandResponse': grpc.unary_unary_rpc_method_handler(
                    servicer.SendCommandResponse,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.SendCommandResponseRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.SendCommandResponseResponse.SerializeToString,
            ),
            'PostTransformFrame': grpc.unary_unary_rpc_method_handler(
                    servicer.PostTransformFrame,
                    request_deserializer=protos_dot_model_dot_v1_dot_math__pb2.TransformFrame.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostTransformFrameResponse.SerializeToString,
            ),
            'SetBaseFrameID': grpc.unary_unary_rpc_method_handler(
                    servicer.SetBaseFrameID,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.SetBaseFrameIDRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.SetBaseFrameIDResponse.SerializeToString,
            ),
            'ClearTransformTree': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearTransformTree,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.ClearTransformTreeRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.ClearTransformTreeResponse.SerializeToString,
            ),
            'GetTeleopInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTeleopInfo,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopInfoRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopInfoResponse.SerializeToString,
            ),
            'PostLanRtcOffer': grpc.unary_unary_rpc_method_handler(
                    servicer.PostLanRtcOffer,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostLanRtcOfferRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostLanRtcOfferResponse.SerializeToString,
            ),
            'SendOnCustomDataChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.SendOnCustomDataChannel,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.SendOnCustomDataChannelRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.SendOnCustomDataChannelResponse.SerializeToString,
            ),
            'PostGenericAPIRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.PostGenericAPIRequest,
                    request_deserializer=protos_dot_model_dot_v1_dot_datapoint__pb2.GenericAPIDatapoint.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostGenericAPIRequestResponse.SerializeToString,
            ),
            'PostGenericAPIUnbufferedRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.PostGenericAPIUnbufferedRequest,
                    request_deserializer=protos_dot_model_dot_v1_dot_datapoint__pb2.GenericAPIDatapoint.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostGenericAPIUnbufferedRequestResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'v1.agent.Agent', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('v1.agent.Agent', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Agent(object):
    """Agent is the Formant Agent gRPC API. 
    """

    @staticmethod
    def StreamData(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/v1.agent.Agent/StreamData',
            protos_dot_model_dot_v1_dot_datapoint__pb2.Datapoint.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.StreamDataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PostData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/PostData',
            protos_dot_model_dot_v1_dot_datapoint__pb2.Datapoint.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.PostDataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PostDataMulti(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/PostDataMulti',
            protos_dot_agent_dot_v1_dot_agent__pb2.PostDataMultiRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.PostDataMultiResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTeleopControlDataStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/v1.agent.Agent/GetTeleopControlDataStream',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopControlDataStreamRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopControlDataStreamResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTeleopHeartbeatStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/v1.agent.Agent/GetTeleopHeartbeatStream',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopHeartbeatStreamRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopHeartbeatStreamResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTelemetryListenerStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/v1.agent.Agent/GetTelemetryListenerStream',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetTelemetryListenerStreamRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetTelemetryListenerStreamResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCustomDataChannelMessageStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/v1.agent.Agent/GetCustomDataChannelMessageStream',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetCustomDataChannelMessageStreamRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetCustomDataChannelMessageStreamResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/CreateEvent',
            protos_dot_agent_dot_v1_dot_agent__pb2.CreateEventRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.CreateEventResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateInterventionRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/CreateInterventionRequest',
            protos_dot_model_dot_v1_dot_intervention__pb2.InterventionRequest.SerializeToString,
            protos_dot_model_dot_v1_dot_intervention__pb2.InterventionRequest.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetInterventionRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/GetInterventionRequest',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetInterventionRequestRequest.SerializeToString,
            protos_dot_model_dot_v1_dot_intervention__pb2.InterventionRequest.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetInterventionResponse(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/GetInterventionResponse',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetInterventionResponseRequest.SerializeToString,
            protos_dot_model_dot_v1_dot_intervention__pb2.InterventionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetStreamsConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/GetStreamsConfiguration',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetStreamsConfigurationRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetStreamsConfigurationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetApplicationConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/GetApplicationConfiguration',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetApplicationConfigurationRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetApplicationConfigurationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetConfigBlobData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/GetConfigBlobData',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetConfigBlobDataRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetConfigBlobDataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAgentConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/GetAgentConfiguration',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetAgentConfigurationRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetAgentConfigurationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBufferMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/GetBufferMetadata',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetBufferMetadataRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetBufferMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def QueryDatapoints(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/QueryDatapoints',
            protos_dot_agent_dot_v1_dot_agent__pb2.QueryDatapointsRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.QueryDatapointsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def QueryEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/QueryEvents',
            protos_dot_agent_dot_v1_dot_agent__pb2.QueryEventsRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.QueryEventsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Health(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/Health',
            protos_dot_agent_dot_v1_dot_agent__pb2.HealthRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.HealthResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCommandRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/GetCommandRequest',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCommandRequestStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/v1.agent.Agent/GetCommandRequestStream',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestStreamRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestStreamResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SendCommandResponse(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/SendCommandResponse',
            protos_dot_agent_dot_v1_dot_agent__pb2.SendCommandResponseRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.SendCommandResponseResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PostTransformFrame(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/PostTransformFrame',
            protos_dot_model_dot_v1_dot_math__pb2.TransformFrame.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.PostTransformFrameResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetBaseFrameID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/SetBaseFrameID',
            protos_dot_agent_dot_v1_dot_agent__pb2.SetBaseFrameIDRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.SetBaseFrameIDResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ClearTransformTree(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/ClearTransformTree',
            protos_dot_agent_dot_v1_dot_agent__pb2.ClearTransformTreeRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.ClearTransformTreeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTeleopInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/GetTeleopInfo',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopInfoRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PostLanRtcOffer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/PostLanRtcOffer',
            protos_dot_agent_dot_v1_dot_agent__pb2.PostLanRtcOfferRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.PostLanRtcOfferResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SendOnCustomDataChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/SendOnCustomDataChannel',
            protos_dot_agent_dot_v1_dot_agent__pb2.SendOnCustomDataChannelRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.SendOnCustomDataChannelResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PostGenericAPIRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/PostGenericAPIRequest',
            protos_dot_model_dot_v1_dot_datapoint__pb2.GenericAPIDatapoint.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.PostGenericAPIRequestResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PostGenericAPIUnbufferedRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/v1.agent.Agent/PostGenericAPIUnbufferedRequest',
            protos_dot_model_dot_v1_dot_datapoint__pb2.GenericAPIDatapoint.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.PostGenericAPIUnbufferedRequestResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
